<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width,initial-scale=1.0">
    {% if page_title == '' -%}
    <title>Home</title>
    {% else -%}
    <title>{{ page_title }}</title>
    {% endif %}
    <link rel="stylesheet" href="base.css" media="screen">
</head>
